package yocaml

  1. Overview
  2. Docs

Module type Required.DATA_TEMPLATE

Describes a language capable of applying a template by assigning data to it (normalized using Yocaml.Required.DATA_INJECTABLE).

type t

The type that describes the template language.

val from : Data.t -> t

from data Transforms a normalized data representation (data) into an associative list of data that can be injected into a template.

val render : ?strict:bool -> (string * t) list -> string -> string

render ?strict parameters content injects parameters data into content and returns the result of the applied content. To inject metadata into a template.